#!/bin/sh

if [ "$1" = "" ] ; then
	exit
fi

# Leopard uses Apache 2, with different conf location
# Leopard also uses config file extras, so setup is simpler

OSXVER=`uname -r | cut -d . -f 1`

if [ $(($OSXVER)) -lt 7 ] || [ $(($OSXVER)) -gt 10 ] ; then
	echo "Unsupported system version."
	exit 1
fi
if [ "$1" != "apache4" ] && [ "$1" != "apache5" ] && [ "$1" != "cgi4" ] && [ "$1" != "cgi5" ] ; then
	exit 1
fi

# specify conf file for testing
if [ "$2" = "" ] ; then
	httpdconf="httpd.conf"
	if [ $(($OSXVER)) -gt 8 ] ; then
		prefix="/etc/apache2"
	else
		prefix="/etc/httpd"
	fi
else
	prefix="."
	httpdconf="$2"
fi

mosxserver=`grep "Mac OS X Server" $prefix/$httpdconf`

# clear out current settings

cp $prefix/$httpdconf $prefix/$httpdconf.phpenablesaved
if [ $(($OSXVER)) -lt 9 ] ; then
	/usr/bin/sed -E -i .phpenabletemp '/^#?LoadModule php[45]_module .*libexec\/httpd\/libphp[45].so$/D' $prefix/$httpdconf
	/usr/bin/sed -E -i .phpenabletemp '/^[[:space:]]*Action php-script \/cgi-bin\/php5?$/D' $prefix/$httpdconf
	if [ "$mosxserver" ] ; then
		/usr/bin/sed -E -i .phpenabletemp '/^[[:space:]]*AddHandler php-script (php|phtml)+$/D' $prefix/$httpdconf
	else
		/usr/bin/sed -E -i .phpenabletemp '/^[[:space:]]*AddHandler php-script .php .phtml$/D' $prefix/$httpdconf
	fi
else
	if [ "$mosxserver" ] ; then
		/usr/bin/sed -E -i .phpenabletemp -e 's,^[[:space:]]*AddType application\/x-httpd-php.*$,#&,g' -e '/^[[:space:]]*AddHandler php-script (php|phtml)+$/D' -e '/^[[:space:]]*Action php-script \/cgi-bin\/php5?$/D' $prefix/$httpdconf
	fi
fi

# then set as asked for

# Leopard cgi5
if [ $(($OSXVER)) -gt 8 ] && [ "$1" = "cgi5" ] ; then
	/usr/bin/sed -E -i .phpenabletemp 's,^#?LoadModule php5_module .*libexec/apache2/libphp5.so$,#LoadModule php5_module libexec/apache2/libphp5.so,' $prefix/$httpdconf
	if [ ! "$mosxserver" ] ; then
		cat > $prefix/other/php5cgi.conf <<EOF
DirectoryIndex index.html index.php
Action php-script /cgi-bin/php5
AddHandler php-script php
AddHandler php-script phtml
EOF
	else
		/usr/bin/sed -E -i .phpenabletemp 's,^([[:space:]]*)#?AddHandler cgi-script cgi$,&\
\1Action php-script \/cgi-bin\/php5\
\1AddHandler php-script php\
\1AddHandler php-script phtml,' $prefix/$httpdconf
	fi

# Leopard apache5
elif [ $(($OSXVER)) -gt 8 ] && [ "$1" = "apache5" ] ; then
	/usr/bin/sed -E -i .phpenabletemp 's,^#?LoadModule php5_module .*libexec/apache2/libphp5.so$,LoadModule php5_module libexec/apache2/libphp5.so,' $prefix/$httpdconf
	if [ ! "$mosxserver" ] ; then
		cat > $prefix/other/php5cgi.conf <<EOF
#DirectoryIndex index.html index.php
#Action php-script /cgi-bin/php5
#AddHandler php-script php
#AddHandler php-script phtml
EOF
	else
		/usr/bin/sed -E -i .phpenabletemp 's,^#([[:space:]]*AddType application\/x-httpd-php.*)$,\1,g' $prefix/$httpdconf
	fi

# <Leopard dso4
elif [ "$1" = "apache4" ] ; then
	/usr/bin/sed -E -i .phpenabletemp 's,libperl.so$,&\
LoadModule php4_module /usr/local/php4/libexec/httpd/libphp4.so,' $prefix/$httpdconf
	/usr/bin/sed -E -i .phpenabletemp 's,^#?AddModule mod_php[45].c$,AddModule mod_php4.c,' $prefix/$httpdconf

# <Leopard dso5
elif [ "$1" = "apache5" ] ; then
	/usr/bin/sed -E -i .phpenabletemp 's,libperl.so$,&\
LoadModule php5_module /usr/local/php5dso/libexec/httpd/libphp5.so,' $prefix/$httpdconf
	/usr/bin/sed -E -i .phpenabletemp 's,^#?AddModule mod_php[45].c$,AddModule mod_php5.c,' $prefix/$httpdconf
	p5d=`grep "<IfModule mod_php5.c>" $prefix/$httpdconf`
	if [ ! "$p5d" ] ; then
		if [ ! "$mosxserver" ] ; then
			/usr/bin/sed -E -i .phpenabletemp 's,^Include /private/etc/httpd/users/\*\.conf$,<IfModule mod_php5.c>\
    AddType application\/x-httpd-php .php\
    AddType application\/x-httpd-php-source .phps\
    <IfModule mod_dir.c>\
        DirectoryIndex index.html index.php\
    <\/IfModule>\
<\/IfModule>\
\
&,' $prefix/$httpdconf
		else
			/usr/bin/sed -E -i .phpenabletemp 's,^Include "/etc/httpd/sites/\*\.conf"$,<IfModule mod_php5.c>\
    AddType application\/x-httpd-php .php\
    AddType application\/x-httpd-php-source .phps\
    <IfModule mod_dir.c>\
        DirectoryIndex index.html index.php\
    <\/IfModule>\
<\/IfModule>\
\
&,' $prefix/$httpdconf
		fi
	fi

# <Leopard cgi4
elif [ "$1" = "cgi4" ] ; then
	/usr/bin/sed -E -i .phpenabletemp 's,libperl.so$,&\
#LoadModule php4_module /usr/local/php4/libexec/httpd/libphp4.so,' $prefix/$httpdconf
	/usr/bin/sed -E -i .phpenabletemp 's,^#?AddModule mod_php[45].c$,#AddModule mod_php4.c,' $prefix/$httpdconf
	if [ "$mosxserver" ] ; then
		/usr/bin/sed -E -i .phpenabletemp 's,^([[:space:]]*)#?AddHandler cgi-script cgi$,&\
\1Action php-script \/cgi-bin\/php\
\1AddHandler php-script php\
\1AddHandler php-script phtml,' $prefix/$httpdconf
	else
		/usr/bin/sed -E -i .phpenabletemp 's,^([[:space:]]*)#?AddHandler cgi-script \.cgi$,&\
\1Action php-script \/cgi-bin\/php\
\1AddHandler php-script .php .phtml,' $prefix/$httpdconf
	fi

# <Leopard cgi5
elif [ "$1" = "cgi5" ] ; then
	/usr/bin/sed -E -i .phpenabletemp 's,libperl.so$,&\
#LoadModule php5_module /usr/local/php5dso/libexec/httpd/libphp5.so,' $prefix/$httpdconf
	/usr/bin/sed -E -i .phpenabletemp 's,^#?AddModule mod_php[45].c$,#AddModule mod_php5.c,' $prefix/$httpdconf
	if [ "$mosxserver" ] ; then
		/usr/bin/sed -E -i .phpenabletemp 's,^([[:space:]]*)#?AddHandler cgi-script cgi$,&\
\1Action php-script \/cgi-bin\/php5\
\1AddHandler php-script php\
\1AddHandler php-script phtml,' $prefix/$httpdconf
	else
		/usr/bin/sed -E -i .phpenabletemp 's,^([[:space:]]*)#?AddHandler cgi-script \.cgi$,&\
\1Action php-script \/cgi-bin\/php5\
\1AddHandler php-script .php .phtml,' $prefix/$httpdconf
	fi
else
	exit 1
fi

rm $prefix/$httpdconf.phpenablesaved
rm $prefix/$httpdconf.phpenabletemp

# don't restart apache if testing
if [ "$2" = "" ] ; then
	httpdproc=`ps -laxc | grep httpd`
	if [ httpdproc ] ; then
		apachectl graceful
	fi
fi
exit 0
